@@ -242,7 +242,7 @@ module Releases = struct
               v4_09; v4_10; v4_11; v4_12; v4_13;
               v4_14; v5_0; v5_1; v5_2; v5_3 ]
 
-  let recent = [ v4_02; v4_03; v4_04; v4_05; v4_06; v4_07; v4_08; v4_09; v4_10; v4_11; v4_12; v4_13; v4_14; v5_0; v5_1; v5_2; v5_3 ]
+  let recent = [ v4_08; v4_09; v4_10; v4_11; v4_12; v4_13; v4_14; v5_0; v5_1; v5_2; v5_3 ]
 
   let latest = v5_3
 
